<?php
/**
 * @package     SP LMS
 *
 * @copyright   Copyright (C) 2010 - 2015 JoomShaper. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// No Direct Access
defined ('_JEXEC') or die('Resticted Aceess');

class SplmsModelCourses extends FOFModel {

	// build query
	public function buildQuery($overrideLimits = false){

		// BEGIN:: Query
		$table = $this->getTable();
		$tableName = $table->getTableName();
		$tableKey = $table->getKeyName();
		$db = $this->getDbo();
		$query = $db->getQuery(true);
		$query->select( array('a.*') );
		$query->from($db->quoteName($tableName, 'a'));
		//Frontend
		if(FOFPlatform::getInstance()->isFrontend()) {

			$query->select($db->quoteName('b.title', 'category_name'));

			$query->join('LEFT', $db->quoteName('#__splms_coursescategories', 'b') . ' ON (' . $db->quoteName('a.splms_coursescategory_id') . ' = ' . $db->quoteName('b.splms_coursescategory_id') . ')');

			// Get Params
			$app = JFactory::getApplication();
			$params   = $app->getMenu()->getActive()->params; // get the active item
			$item_type 	= $params->get('item_type', '');
			$ordering 		= $params->get('ordering', ' DESC');
			$category_id 	= $params->get('category_id', '');

			if ($item_type) {
				$query->where($db->quoteName('a.featured_course')." = " . $db->quote(1));
			}
			if ($category_id) {
				$query->where($db->quoteName('a.splms_coursescategory_id')." = " . $db->quote($category_id));
			}

			//Language
			$query->where('a.language in (' . $db->quote(JFactory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
			//Access
			$query->where($db->quoteName('a.access')." IN (" . implode( ',', JFactory::getUser()->getAuthorisedViewLevels() ) . ")");
			//Enabled
			$query->where($db->qn('a.enabled')." = ".$db->quote('1'));
			// ordering
			$query->order($db->quoteName('a.ordering') . $ordering);

		}

		if (!$overrideLimits){
			if (!FOFPlatform::getInstance()->isFrontend()) {
				$order = $this->getState('filter_order', null, 'cmd');

				if (!in_array($order, array_keys($table->getData()))){
					$order = $tableKey;
				}
				$dir = $this->getState('filter_order_Dir', 'ASC', 'cmd');
				$query->order($order . ' ' . $dir);
			}
		}

		// Call the behaviors
		if(!FOFPlatform::getInstance()->isFrontend()) {
			$this->modelDispatcher->trigger('onAfterBuildQuery', array(&$this, &$query));
		}

		return $query;

	}

	//if item not found
	public function &getItem($id = null) {
		$item = parent::getItem($id);

		if(FOFPlatform::getInstance()->isFrontend()) {

			if($item->splms_course_id) {
				return $item;
			} else {
				return JError::raiseError(404, JText::_('COM_SPLMS_NO_ITEMS_FOUND'));
			}

		} else {
			return $item;
		}
	}

	// Get Couse Teachers by Course ID
	public static function getCourseTeachers($course) {
		$lessons_model = FOFModel::getTmpInstance('Lessons', 'SplmsModel');
		$lessons = $lessons_model->getLessons($course);
		$ids = array();
		foreach ($lessons as $lesson) {
			$ids[] = $lesson->splms_teacher_id;
		}

		$ids = array_unique($ids);
		$ids = implode(',',$ids);

		if ($ids) {
			$db = JFactory::getDbo();
			$query = $db->getQuery(true);

			$query->select($db->quoteName(array('splms_teacher_id', 'title', 'slug', 'image', 'experience', 'specialist_in', 'website')));
			$query->from($db->quoteName('#__splms_teachers'));
			$query->where($db->quoteName('enabled')." = 1");
			$query->where($db->quoteName('splms_teacher_id')." IN (".$ids . ")");
			$query->order('ordering DESC');

			$db->setQuery($query);

			$items = $db->loadObjectList();

			foreach ($items as &$item) {
				$item->url = JRoute::_('index.php?option=com_splms&view=teacher&id='.$item->splms_teacher_id.':'.$item->slug . SplmsHelper::getItemid('teachers'));

				//$item->url = JRoute::_('index.php?option=com_splms&view=teacher&id='. $item->splms_teacher_id);
			}
		}else{
			$items= array();
		}

		return $items;
	}


	// Get Course By Course id
	public static function getCourse($id) {
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		$query->select($db->quoteName(array('a.splms_course_id', 'a.title', 'a.slug', 'a.image', 'a.course_time', 'a.price')));
		$query->select($db->quoteName('b.title', 'category_name'));
		$query->from($db->quoteName('#__splms_courses', 'a'));
		$query->join('LEFT', $db->quoteName('#__splms_coursescategories', 'b') . ' ON (' . $db->quoteName('a.splms_coursescategory_id') . ' = ' . $db->quoteName('b.splms_coursescategory_id') . ')');

		$query->where($db->quoteName('a.enabled')." = 1");
		$query->where($db->quoteName('a.splms_course_id')." = ".$db->quote($id));
		$query->order('a.ordering DESC');

		$db->setQuery($query);

		$result = $db->loadObject();

		$result->url = JRoute::_('index.php?option=com_splms&view=course&id='.$result->splms_course_id.':'.$result->slug . SplmsHelper::getItemid('courses'));

		return $result;
	}

	// Get Course By Course id
	public static function getAllCourses() {

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		// Select all records from the user profile table where key begins with "custom.".
		// Order it by the ordering field.
		$query->select($db->quoteName(array('splms_course_id', 'title', 'slug', 'image', 'short_description')));
		$query->from($db->quoteName('#__splms_courses'));
		$query->where($db->quoteName('enabled')." = 1");
		$query->order('ordering DESC');

		// Reset the query using our newly populated query object.
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).

		$results = $db->loadObjectList();

		foreach ($results as &$result) {
			$result->url = JRoute::_('index.php?option=com_splms&view=course&id='.$result->splms_course_id.':'.$result->slug . SplmsHelper::getItemid('courses'));
		}

		//$result->url = JRoute::_('index.php?option=com_splms&view=course&id='. $result->splms_course_id);
		return $results;
	}

	// Check user already buy course
	public static function getIsbuycourse($user_id, $course_id) {

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		// Select all records from the user profile table where key begins with "custom.".
		// Order it by the ordering field.
		$query->select($db->quoteName(array('splms_order_id')));
		$query->from($db->quoteName('#__splms_orders'));
		$query->where($db->quoteName('enabled')." = 1");
		$query->where($db->quoteName('splms_course_id')." = ".$db->quote($course_id));
		$query->where($db->quoteName('order_user_id')." = ".$db->quote($user_id));
		$query->order('ordering DESC');

		// Reset the query using our newly populated query object.
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$result = $db->loadObject();

		return $result;
	}

	// Get users puchased item
	public static function getPurchasedCourse($user_id) {

		$db = JFactory::getDbo();
		// Create a new query object.
		$query = $db->getQuery(true);
		$query->select($db->quoteName(array('order_user_id', 'splms_course_id', 'enabled')));
		$query->from($db->quoteName('#__splms_orders'));
		$query->where($db->quoteName('order_user_id')." = ".$db->quote($user_id));
		$query->order('ordering DESC');
		$db->setQuery($query);
		$results = $db->loadObjectList();

		foreach ($results as &$result) {
			$result->course_info = self::getCourse($result->splms_course_id);

			$result->course_name = $result->course_info->title;
			$result->url  = $result->course_info->url;
		}

		return $results;
	}

	// Get Quizzes By Course id
	public static function getQuizzes($course_id) {
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		$query->select($db->quoteName(array('splms_quizquestion_id', 'title', 'slug', 'quiz_type')));
		$query->from($db->quoteName('#__splms_quizquestions'));
		$query->where($db->quoteName('enabled') ." = 1");
		$query->where($db->quoteName('splms_course_id')." = ".$db->quote($course_id));
		$query->order('ordering DESC');

		$db->setQuery($query);

		$items = $db->loadObjectList();

		foreach ($items as &$item) {
			$item->url = JRoute::_('index.php?option=com_splms&view=quizquestion&id='.$item->splms_quizquestion_id.':'.$item->slug . SplmsHelper::getItemid('quizquestions'));
		}

		return $items;
	}

	//Get Related Artists
	public function getRelatedCourses($course_name, $course_id, $cat_id, $limit = 3) {

		$search = preg_replace('#\xE3\x80\x80#s', " ", htmlspecialchars(trim($course_name)));
		$search_array = explode(" ", $search);

		$str_tag_ids = implode(' OR ', array_map(function ($entry) {
			return "a.title LIKE '%" . $entry . "%'";
		}, $search_array));

		$str_tag_ids = $str_tag_ids . " OR a.splms_coursescategory_id = '%" . $cat_id . "%'";

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);
		$query->select( array('a.splms_course_id', 'a.title', 'a.slug', 'a.course_sub_title', 'a.course_time', 'a.image') );
		$query->select($db->quoteName('b.title', 'category_name'));
		$query->from($db->quoteName('#__splms_courses', 'a'));
		$query->join('LEFT', $db->quoteName('#__splms_coursescategories', 'b') . ' ON (' . $db->quoteName('a.splms_coursescategory_id') . ' = ' . $db->quoteName('b.splms_coursescategory_id') . ')');
		//$query->where('a.title in (' . " LIKE '%" . implode("%' OR " . $db->quoteName('a.title') . " LIKE '%", $search_array) . "%'" ',' . $db->quote('*') . ')');
		//$query->where($db->quoteName('a.title') . " LIKE '%" . implode("%' OR " . $db->quoteName('a.title') . " LIKE '%", $search_array) . "%'");
		$query->where($db->quoteName('a.splms_course_id')." != ".$db->quote($course_id));

		if ($str_tag_ids) {
			$query->where($str_tag_ids);
		}

		$query->where($db->quoteName('a.enabled')." = ".$db->quote('1'));

		$db->setQuery($query);
		$results = $db->loadObjectList();

		foreach ($results as &$result) {
			$result->url  = JRoute::_('index.php?option=com_splms&view=course&id='.$result->splms_course_id.':'.$result->slug . SplmsHelper::getItemid('courses'));
		}

		// $uniqueArtist = array();
		// foreach ($results as &$result) {
		// 	$artist_decodes = json_decode($result->artists);
		// 	foreach ($artist_decodes as $key => $artist_decode) {
		// 		if (array_search($artist_decode,$uniqueArtist)===false) {
		// 			$uniqueArtist[] = $artist_decode;
		// 		}
		// 	}
		// }

		//$artist_details = self::getRelatedArtistDetails($uniqueArtist, $limit);

		return $results;
	}




}
