<?php
/**
 * @package     SP LMS
 *
 * @copyright   Copyright (C) 2010 - 2015 JoomShaper. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// No Direct Access
defined ('_JEXEC') or die('Resticted Aceess');

class SplmsModelEvents extends FOFModel {

	// build query
	public function buildQuery($overrideLimits = false){
		// BEGIN:: Query
		$table = $this->getTable();
		$tableName = $table->getTableName();
		$tableKey = $table->getKeyName();
		$db = $this->getDbo();
		$query = $db->getQuery(true);
		$query->select('*')->from($db->qn($tableName, 'a'));
		//Frontend
		if(FOFPlatform::getInstance()->isFrontend()) {
			$now = JHtml::_('date', JFactory::getDate(), 'Y-m-d');
			// Get Params
			$app 				= JFactory::getApplication();
			$params   	= $app->getMenu()->getActive()->params; // get the active item
			$ordering 	= $params->get('ordering', ' DESC');
			$category_id 	= $params->get('category_id', '');

			if ($category_id) {
				$query->where($db->quoteName('a.splms_eventcategory_id')." = " . $db->quote($category_id));
			}

			if ($ordering=='upcoming') {
				$query->where($db->quoteName('a.event_start_date') . ' > ' . $db->quote($now));
				$query->order($db->quoteName('a.event_start_date') . ' ASC');
			} elseif ($ordering=='latest') {
				$query->where($db->quoteName('a.event_start_date') . ' <= ' . $db->quote($now));
				$query->order($db->quoteName('a.event_start_date') . ' DESC');
			} elseif ($ordering== 'asc') {
				$query->order($db->quoteName('a.ordering') . ' ASC');
			} else {
				$query->order($db->quoteName('a.ordering') . ' DESC');
			}

			// Get Params
			$app = JFactory::getApplication();
			$params   = $app->getMenu()->getActive()->params; // get the active item
			//Language
			$query->where('a.language in (' . $db->quote(JFactory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
			//Access
			$query->where($db->quoteName('a.access')." IN (" . implode( ',', JFactory::getUser()->getAuthorisedViewLevels() ) . ")");

			//Enabled
			$query->where($db->qn('a.enabled')." = ".$db->quote('1'));
			// ordering
			$query->order('a.ordering DESC');
		}

		if (!$overrideLimits){
			if (!FOFPlatform::getInstance()->isFrontend()) {
				$order = $this->getState('filter_order', null, 'cmd');

				if (!in_array($order, array_keys($table->getData()))){
					$order = $tableKey;
				}
				$dir = $this->getState('filter_order_Dir', 'ASC', 'cmd');
				$query->order($order . ' ' . $dir);
			}
		}

		// Call the behaviors
		if(!FOFPlatform::getInstance()->isFrontend()) {
			$this->modelDispatcher->trigger('onAfterBuildQuery', array(&$this, &$query));
		}
		return $query;
	}

	//if item not found
	public function &getItem($id = null) {
		$item = parent::getItem($id);

		if(FOFPlatform::getInstance()->isFrontend()) {

			if($item->splms_event_id) {
				return $item;
			} else {
				return JError::raiseError(404, JText::_('COM_SPLMS_NO_ITEMS_FOUND'));
			}

		} else {
			return $item;
		}
	}

	// Get All Events
	public static function getAllEvents() {

		// Now time
		$nowDate = JFactory::getDate()->format('Y-m-d');
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		// Select all records from the user profile table where key begins with "custom.".
		// Order it by the ordering field.
		$query->select($db->quoteName(array('splms_event_id', 'title', 'slug', 'image', 'description', 'event_time', 'event_end_time','splms_speaker_id')));
		$query->from($db->quoteName('#__splms_events'));
		$query->where($db->quoteName('enabled')." = 1");
		//Time sorting
		$query->where($db->qn('event_start_date')." > ".$db->quote($nowDate));
		//order
		$query->order($db->quoteName('event_start_date') . ' ASC');
		$query->order('ordering DESC');

		// Reset the query using our newly populated query object.
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).

		$results = $db->loadObjectList();

		foreach ($results as &$result) {
			$result->url = JRoute::_('index.php?option=com_splms&view=event&id='.$result->splms_event_id.':'.$result->slug . SplmsHelper::getItemid('events'));
		}

		//$result->url = JRoute::_('index.php?option=com_splms&view=course&id='. $result->splms_course_id);

		return $results;
	}


	// Get Event category by event
	public static function getEventCategory($id) {

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		// Select all records from the user profile table where key begins with "custom.".
		// Order it by the ordering field.
		$query->select($db->quoteName(array('splms_eventcategory_id', 'title', 'slug', 'image')));
		$query->from($db->quoteName('#__splms_eventcategories'));
		$query->where($db->quoteName('enabled')." = 1");
		$query->where($db->quoteName('splms_eventcategory_id')." = ".$db->quote($id));
		$query->order('ordering DESC');

		// Reset the query using our newly populated query object.
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$result = $db->loadObject();

		$result->url = JRoute::_('index.php?option=com_splms&view=eventcategory&id='.$result->splms_eventcategory_id.':'.$result->slug . SplmsHelper::getItemid('events'));
		//$result->url = JRoute::_('index.php?option=com_splms&view=eventcategory&id='. $result->splms_eventcategory_id);

		return $result;
	}

	// Get Event Speakers by event
	public static function getEventSpeakers($ids) {

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		if (is_array($ids) == false) {
			$replaceArr  	 = array("\"","[","]");
			$speakerids 	 = str_replace( $replaceArr,"", $ids);
		}else{
			$speakerids = implode(',', $ids);
		}


		if (!empty($speakerids)) {
			$query->select($db->quoteName(array('splms_speaker_id', 'title', 'slug', 'designation', 'image')));
			$query->from($db->quoteName('#__splms_speakers'));
			$query->where($db->quoteName('enabled')." = 1");
			$query->where($db->quoteName('splms_speaker_id')." IN (". $speakerids . ")");
			$query->order('ordering DESC');

			$db->setQuery($query);

			$items = $db->loadObjectList();

			foreach ($items as &$item) {
				$item->url = JRoute::_('index.php?option=com_splms&view=speaker&id='.$item->splms_speaker_id.':'.$item->slug . SplmsHelper::getItemid('speakers'));

				//$item->url = JRoute::_('index.php?option=com_splms&view=speaker&id='.$item->splms_speaker_id.':'.$item->slug );
			}
		}else{
			$items='';
		}

		return $items;
	}

	//Get Events By category
	public static function getEventByCategory($eventcategory_id) {
		$db = JFactory::getDbo();
		// Create a new query object.
		$query = $db->getQuery(true);

		// Select all records from the user profile table where key begins with "custom.".
		// Order it by the ordering field.
		$query->select($db->quoteName(array('splms_event_id', 'title', 'slug', 'description', 'image', 'event_start_date', 'event_end_date', 'event_time', 'event_address', 'price','splms_speaker_id')));
		$query->from($db->quoteName('#__splms_events'));
		$query->where($db->quoteName('enabled')." = 1");
		$query->where($db->quoteName('splms_eventcategory_id')." = ".$db->quote($eventcategory_id));
		$query->order('ordering DESC');

		// Reset the query using our newly populated query object.
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$results = $db->loadObjectList();

		foreach ($results as &$result) {
			$result->url = JRoute::_('index.php?option=com_splms&view=event&id='.$result->splms_event_id.':'.$result->slug . SplmsHelper::getItemid('events'));
			//$result->url = JRoute::_('index.php?option=com_splms&view=event&id='. $result->splms_event_id);
		}

		return $results;
	}


}
