<?php
/**
 * @package     SP LMS
 *
 * @copyright   Copyright (C) 2010 - 2015 JoomShaper. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// No Direct Access
defined ('_JEXEC') or die('Resticted Aceess');

class SplmsModelLessons extends FOFModel {

	protected static $message = '';
	protected static $files = array();

	// build query
	public function buildQuery($overrideLimits = false){

		// BEGIN:: Query
		$table = $this->getTable();
		$tableName = $table->getTableName();
		$tableKey = $table->getKeyName();
		$db = $this->getDbo();
		$query = $db->getQuery(true);
		$query->select('*')->from($db->qn($tableName, 'a'));
		//Frontend
		if(FOFPlatform::getInstance()->isFrontend()) {
			// Get Params
			$app = JFactory::getApplication();
			$params   = $app->getMenu()->getActive()->params; // get the active item
			//Language
			$query->where('a.language in (' . $db->quote(JFactory::getLanguage()->getTag()) . ',' . $db->quote('*') . ')');
			//Access
			$query->where($db->quoteName('a.access')." IN (" . implode( ',', JFactory::getUser()->getAuthorisedViewLevels() ) . ")");
			//Enabled
			$query->where($db->qn('a.enabled')." = ".$db->quote('1'));
			// ordering
			$query->order('a.ordering DESC');

		}

		if (!$overrideLimits){
			if (!FOFPlatform::getInstance()->isFrontend()) {
				$order = $this->getState('filter_order', null, 'cmd');

				if (!in_array($order, array_keys($table->getData()))){
					$order = $tableKey;
				}
				$dir = $this->getState('filter_order_Dir', 'ASC', 'cmd');
				$query->order($order . ' ' . $dir);
			}
		}

		// Call the behaviors
		if(!FOFPlatform::getInstance()->isFrontend()) {
			$this->modelDispatcher->trigger('onAfterBuildQuery', array(&$this, &$query));
		}

		return $query;
	}

	//if item not found
	public function &getItem($id = null) {
		$item = parent::getItem($id);

		if(FOFPlatform::getInstance()->isFrontend()) {

			if($item->splms_lesson_id) {
				return $item;
			} else {
				return JError::raiseError(404, JText::_('COM_SPLMS_NO_ITEMS_FOUND'));
			}

		} else {
			return $item;
		}
	}

	// Get Lessons by course ID
	public static function getLessons($course_id) {

		$teachers_model = FOFModel::getTmpInstance('Teachers', 'SplmsModel');

		$db = JFactory::getDbo();
		// Create a new query object.
		$query = $db->getQuery(true);

		// Select all records from the user profile table where key begins with "custom.".
		// Order it by the ordering field.
		$query->select($db->quoteName(array('splms_lesson_id', 'title', 'slug', 'splms_teacher_id', 'ordering', 'created_on', 'video_duration', 'lesson_type', 'attachment')));
		$query->from($db->quoteName('#__splms_lessons'));
		$query->where($db->quoteName('enabled')." = 1");
		$query->where($db->quoteName('splms_course_id')." = ".$db->quote($course_id));
		//$query->where($db->quoteName('access')." IN (" . implode( ',', JFactory::getUser()->getAuthorisedViewLevels() ) . ")");
		$query->order('ordering DESC');
		// Reset the query using our newly populated query object.
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$results = $db->loadObjectList();

		foreach ($results as &$result) {
			$result->teacher_name = $teachers_model->getTeacher($result->splms_teacher_id);
			$result->teacher_url  = JRoute::_('index.php?option=com_splms&view=teacher&id='. $result->splms_teacher_id);
			$result->lesson_url = JRoute::_('index.php?option=com_splms&view=lesson&id='.$result->splms_lesson_id.':'.$result->slug . SplmsHelper::getItemid('courses'));
		}

		return $results;
	}


	// Get Free Lessons of course by course ID
	public static function getCourseFreeLesson($course_id) {
		$db = JFactory::getDbo();
		// Create a new query object.
		$query = $db->getQuery(true);

		// Select all records from the user profile table where key begins with "custom.".
		// Order it by the ordering field.
		$query->select($db->quoteName(array('splms_lesson_id', 'title', 'slug', 'video_url')));
		$query->from($db->quoteName('#__splms_lessons'));
		$query->where($db->quoteName('enabled')." = 1");
		$query->where($db->quoteName('lesson_type')." = 0");
		$query->where($db->quoteName('splms_course_id')." = ".$db->quote($course_id));
		$query->setLimit(1);
		$query->order('ordering ASC');
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$results = $db->loadObjectList();

		return $results;
	}


	// Get Lessons By Teacher ID (Teachers Lessons)
	public static function getTeacherLessons($teacher_id) {

		$courses_model = FOFModel::getTmpInstance('Courses', 'SplmsModel');

		$db = JFactory::getDbo();
		// Create a new query object.
		$query = $db->getQuery(true);

		// Select all records from the user profile table where key begins with "custom.".
		// Order it by the ordering field.
		$query->select($db->quoteName(array('splms_lesson_id', 'title', 'slug', 'splms_course_id', 'video_duration', 'created_on', 'lesson_type')));
		$query->from($db->quoteName('#__splms_lessons'));
		$query->where($db->quoteName('enabled')." = 1");
		$query->where($db->quoteName('splms_teacher_id')." = ".$db->quote($teacher_id));
		$query->order('ordering DESC');

		// Reset the query using our newly populated query object.
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$results = $db->loadObjectList();

		foreach ($results as &$result) {
			$result->lesson_url = JRoute::_('index.php?option=com_splms&view=lesson&id='.$result->splms_lesson_id.':'.$result->slug . SplmsHelper::getItemid('courses'));
			$result->get_course_info = $courses_model->getCourse($result->splms_course_id);
		}

		return $results;
	}

	public static function removeAttachmentByID($lessonid = '') {
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);
		$fields = array($db->quoteName('attachment') . ' = ' . $db->quote(NULL) );
		$conditions = array($db->quoteName('splms_lesson_id') . ' = '. $db->quote($lessonid) );
		$query->update($db->quoteName('#__splms_lessons'))->set($fields)->where($conditions);
		$db->setQuery($query);
		$result = $db->execute();

        return true;
	}

	// **** Attachment Upload system **** //
	protected static function existAttachment($lesson_id){
		$lmsdb = JFactory::getDbo();
		$lmsquery = $lmsdb->getQuery(true);
		$lmsquery->select('attachment');
		$lmsquery->from($lmsdb->quoteName('#__splms_lessons'));
		$lmsquery->where($lmsdb->quoteName('splms_lesson_id')." = ".$lesson_id);
		$lmsdb->setQuery($lmsquery);
		$result = $lmsdb->loadObject();
		return $result;
	}

	// check file type
	protected static function fileExtensionCheck($file,$allowed){
		$ext = pathinfo($file['name'], PATHINFO_EXTENSION);
		if(in_array( strtolower($ext), $allowed) ) {
			return true;
		}
		return false;
	}

	protected function onBeforeSave(&$model, &$data){

		$jinput 	= JFactory::getApplication()->input;
		$file = $jinput->files->get('attachment');

		$lesson_id = $model['splms_lesson_id'];

		if ( $file['name']!= '' && $file['name']) {
			if ( self::fileExtensionCheck($file, array('png', 'jpg', 'pdf', 'zip') )) {
				self::$files['attachment'] = $file;
			}else{
				throw new RuntimeException(JText::_('INVALID_FILE_TYPE'), 1);
			}

			// has acchatment before
			$exist_attachment = '';
			$exist_attachment = self::existAttachment($lesson_id)->attachment;

			// delete attachment
			if ($exist_attachment != '') {
				JFile::delete(JPATH_ROOT. '/media/com_splms/lessons/attachments/' .$exist_attachment);
			}
		}

		// unset attachment
		unset($model['attachment']);

		return true;
	}

	protected function onAfterSave(&$model){

		$app = JFactory::getApplication();
		$jinput 	= JFactory::getApplication()->input;
		// Get Lesson ID
		$lesson_id = $model->splms_lesson_id;
		// Get attachment file

		$attachment_file = (self::$files) ? self::$files['attachment'] : '' ;

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		// has file
		if ($attachment_file != '') {
			$folder_path = JPATH_ROOT . '/media/com_splms/lessons/attachments/' . $lesson_id;

			if (!JFolder::exists( $folder_path )) {
				JFolder::create($folder_path);
			}

			// Cleans the name of teh file by removing weird characters
			$filename = JFile::makeSafe($attachment_file['name']);

			$src = $attachment_file['tmp_name'];
			//JFolder::create($folder_path);

			if (JFile::upload($src, $folder_path. '/' .$attachment_file['name'])) {
				// Fields to update.
				$fields = array(
				    $db->quoteName('attachment') . ' = ' . $db->quote('/' . $lesson_id . '/' . $attachment_file['name'] )
				);
				//$query->update($db->quoteName('#__splms_lessons'))->set('attachment')->where();
				$query->update($db->quoteName('#__splms_lessons'))->set($fields)->where($db->quoteName('splms_lesson_id') . ' = ' . $lesson_id);
				$db->setQuery($query);
				$result = $db->execute();
			}else{
				return JFactory::getApplication()->enqueueMessage('Couldn\'t update file ', 'error');
			}
		} // END:: has file


		return true;

	}


}
